summaryrefslogtreecommitdiff
path: root/lib
diff options
context:
space:
mode:
authoryorhel <yorhel@1fe2e327-d9db-4752-bcf7-ef0cb4a1748b>2008-08-20 14:17:47 +0000
committeryorhel <yorhel@1fe2e327-d9db-4752-bcf7-ef0cb4a1748b>2008-08-20 14:17:47 +0000
commitd4368e6342088e8d244cd82dcecce94e74f18299 (patch)
tree90033eb3ce8c0953c5575968781ddd37c1866d71 /lib
parentcbd1e5abe69b7ad6e92b95142123e99f544b747e (diff)
Converted relation graphs to PNG
git-svn-id: svn://vndb.org/vndb@101 1fe2e327-d9db-4752-bcf7-ef0cb4a1748b
Diffstat (limited to 'lib')
-rw-r--r--lib/ChangeLog4
-rw-r--r--lib/Multi/RG.pm6
2 files changed, 7 insertions, 3 deletions
diff --git a/lib/ChangeLog b/lib/ChangeLog
index 7b97bb63..756f6a9a 100644
--- a/lib/ChangeLog
+++ b/lib/ChangeLog
@@ -14,6 +14,10 @@ TODO:
- Fixed bug with the infinite thumbnail generation message when the server
doesn't respond within one second.
- Rewrote VNDB::Util::DB::sqlprint to use server-side prepared statements
+ - Added two new foreign key constraints:
+ changes (causedby) -> changes (id)
+ threads (id, count) -> threads_posts (tid, num)
+ - Converted relation graphs to PNG
1.21 - 2008-08-16 (r90)
- Added !vn and !uptime commands to Multi::IRC
diff --git a/lib/Multi/RG.pm b/lib/Multi/RG.pm
index 8c45014a..37037a96 100644
--- a/lib/Multi/RG.pm
+++ b/lib/Multi/RG.pm
@@ -192,14 +192,14 @@ sub buildgraph {
$gid = $gid->fetchrow_arrayref->[0];
$_[HEAP]{gid} = [
$gid,
- sprintf('%s/%02d/%d.gif', $_[HEAP]{imgdir}, $gid % 100, $gid),
+ sprintf('%s/%02d/%d.png', $_[HEAP]{imgdir}, $gid % 100, $gid),
];
# roughly equivalent to:
# cat layout.txt | dot -Tgif -o graph.gif -Tcmapx
$_[HEAP]{proc} = POE::Wheel::Run->new(
Program => $_[HEAP]{dot},
- ProgramArgs => [ '-Tgif', '-o', $_[HEAP]{gid}[1], '-Tcmapx' ],
+ ProgramArgs => [ '-Tpng', '-o', $_[HEAP]{gid}[1], '-Tcmapx' ],
StdioFilter => POE::Filter::Stream->new(),
StdinEvent => 'proc_stdin',
StdoutEvent => 'proc_stdout',
@@ -192,14 +192,14 @@ sub buildgraph {
];
# roughly equivalent to:
- # cat layout.txt | dot -Tgif -o graph.gif -Tcmapx
+ # cat layout.txt | dot -Tpng -o graph.png -Tcmapx
$_[HEAP]{proc} = POE::Wheel::Run->new(
Program => $_[HEAP]{dot},